@@ -28,7 +28,7 @@ id_wrap = lambda indent : [indent, "",
 struct_wrap = lambda indent : [indent, "",
                                ("  ","",1,1)]
 
-class Record:
+class Record(object):
     """Holds info from a KEGG Ligand/Compound record.
 
     Members:
@@ -74,9 +74,8 @@ class Record:
                            [self.entry])
     def _name(self):
         return _write_kegg("NAME",
-                           map(lambda l:
-                               _wrap_kegg(l, wrap_rule = name_wrap),
-                               self.name))
+                           [_wrap_kegg(l, wrap_rule = name_wrap) \
+                            for l in self.name])
     def _formula(self):
         return _write_kegg("FORMULA",
                            [self.formula])
