@@ -6,13 +6,14 @@
 """Atom class, used in Structure objects."""
 
 import numpy
+import warnings
 
 from Bio.PDB.Entity import DisorderedEntityWrapper
 from Bio.PDB.PDBExceptions import PDBConstructionWarning
 from Bio.PDB.Vector import Vector
 from Bio.Data import IUPACData
 
-class Atom:
+class Atom(object):
     def __init__(self, name, coord, bfactor, occupancy, altloc, fullname, serial_number,
                  element=None):
         """
@@ -94,7 +95,6 @@ class Atom:
                 msg = "Could not assign element %r for Atom (name=%s) with given element %r" \
                       % (putative_element, self.name, element)
                 element = ""
-            import warnings
             warnings.warn(msg, PDBConstructionWarning)
                 
         return element
