@@ -18,12 +18,13 @@ from Bio.PDB.parse_pdb_header import _parse_pdb_header_list
 # If PDB spec says "COLUMNS 18-20" this means line[17:20]
 
 
-class PDBParser:
+class PDBParser(object):
     """
     Parse a PDB file and return a Structure object.
     """
 
-    def __init__(self, PERMISSIVE=1, get_header=0, structure_builder=None):
+    def __init__(self, PERMISSIVE=True, get_header=False,
+                 structure_builder=None, QUIET=False):
         """
         The PDB parser call a number of standard methods in an aggregated
         StructureBuilder object. Normally this object is instanciated by the
@@ -31,11 +32,17 @@ class PDBParser:
         object, the latter is used instead.
 
         Arguments:
-        o PERMISSIVE - int, if this is 0 exceptions in constructing the
-        SMCRA data structure are fatal. If 1 (DEFAULT), the exceptions are 
-        caught, but some residues or atoms will be missing. THESE EXCEPTIONS 
-        ARE DUE TO PROBLEMS IN THE PDB FILE!.
+        
+        o PERMISSIVE - Evaluated as a Boolean. If false, exceptions in
+        constructing the SMCRA data structure are fatal. If true (DEFAULT),
+        the exceptions are caught, but some residues or atoms will be missing.
+        THESE EXCEPTIONS ARE DUE TO PROBLEMS IN THE PDB FILE!.
+
         o structure_builder - an optional user implemented StructureBuilder class. 
+
+        o QUIET - Evaluated as a Boolean. If true, warnings issued in constructing
+        the SMCRA data will be supressed. If false (DEFAULT), they will be shown.
+        These warnings might be indicative of problems in the PDB file!        
         """
         if structure_builder!=None:
             self.structure_builder=structure_builder
@@ -44,7 +51,8 @@ class PDBParser:
         self.header=None
         self.trailer=None
         self.line_counter=0
-        self.PERMISSIVE=PERMISSIVE
+        self.PERMISSIVE=bool(PERMISSIVE)
+        self.QUIET=bool(QUIET)
 
     # Public methods
 
@@ -55,6 +63,11 @@ class PDBParser:
         o id - string, the id that will be used for the structure
         o file - name of the PDB file OR an open filehandle
         """
+
+        if self.QUIET:
+            warning_list = warnings.filters[:]
+            warnings.filterwarnings('ignore', category=PDBConstructionWarning)
+            
         self.header=None
         self.trailer=None
         # Make a StructureBuilder instance (pass id of structure as parameter)
@@ -69,6 +82,10 @@ class PDBParser:
         structure = self.structure_builder.get_structure()
         if handle_close:
             file.close()
+        
+        if self.QUIET:
+            warnings.filters = warning_list
+        
         return structure
 
     def get_header(self):
@@ -91,6 +108,7 @@ class PDBParser:
     def _get_header(self, header_coords_trailer):
         "Get the header of the PDB file, return the rest."
         structure_builder=self.structure_builder
+        i = 0
         for i in range(0, len(header_coords_trailer)):
             structure_builder.set_line_counter(i+1)
             line=header_coords_trailer[i]
@@ -249,7 +267,7 @@ class PDBParser:
     def _handle_PDB_exception(self, message, line_counter):
         """
         This method catches an exception that occurs in the StructureBuilder
-        object (if PERMISSIVE==1), or raises it again, this time adding the 
+        object (if PERMISSIVE), or raises it again, this time adding the 
         PDB line number to the error message.
         """
         message="%s at line %i." % (message, line_counter)
@@ -268,7 +286,7 @@ if __name__=="__main__":
 
     import sys
 
-    p=PDBParser(PERMISSIVE=1)
+    p=PDBParser(PERMISSIVE=True)
 
     filename = sys.argv[1]
     s=p.get_structure("scr", filename)
