@@ -3,42 +3,32 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
-# make yield compatible with Python 2.2
-from __future__ import generators
+"""Calculation of residue depth using command line tool MSMS.
 
-from Numeric import array, sum, sqrt
-import tempfile
-import os
-import sys
-
-from Bio.PDB import *
-from AbstractPropertyMap import AbstractPropertyMap
-
-__doc__="""
-Calculation of residue depth (using Michel Sanner's MSMS program for the
-surface calculation).
+This module uses Michel Sanner's MSMS program for the surface calculation
+(specifically commands msms and pdb_to_xyzr). See:
+http://mgltools.scripps.edu/packages/MSMS
 
 Residue depth is the average distance of the atoms of a residue from 
 the solvent accessible surface.
 
 Residue Depth:
 
-    rd=ResidueDepth(model, pdb_file)
-
-    print rd[(chain_id, res_id)]
+    >>> rd = ResidueDepth(model, pdb_file)
+    >>> print rd[(chain_id, res_id)]
 
 Direct MSMS interface:
 
     Typical use:
 
-        surface=get_surface("1FAT.pdb")
+        >>> surface = get_surface("1FAT.pdb")
 
     Surface is a Numeric array with all the surface 
     vertices.  
 
     Distance to surface:
 
-        dist=min_dist(coord, surface)
+        >>> dist = min_dist(coord, surface)
 
     where coord is the coord of an atom within the volume
     bound by the surface (ie. atom depth).
@@ -46,9 +36,19 @@ Direct MSMS interface:
     To calculate the residue depth (average atom depth
     of the atoms in a residue):
 
-    rd=residue_depth(residue, surface)
+        >>> rd = residue_depth(residue, surface)
 """
 
+import os
+import tempfile
+
+import numpy
+
+from Bio.PDB import Selection
+from Bio.PDB.AbstractPropertyMap import AbstractPropertyMap
+from Bio.PDB.Polypeptide import is_aa
+
+
 def _read_vertex_array(filename):
     """
     Read the vertex list into a Numeric array.
@@ -63,7 +63,7 @@ def _read_vertex_array(filename):
         vl=map(float, sl[0:3])
         vertex_list.append(vl)
     fp.close()
-    return array(vertex_list)
+    return numpy.array(vertex_list)
 
 def get_surface(pdb_file, PDB_TO_XYZR="pdb_to_xyzr", MSMS="msms"):
     """
@@ -76,14 +76,18 @@ def get_surface(pdb_file, PDB_TO_XYZR="pdb_to_xyzr", MSMS="msms"):
     # extract xyz and set radii
     xyz_tmp=tempfile.mktemp()
     PDB_TO_XYZR=PDB_TO_XYZR+" %s > %s"
-    make_xyz=PDB_TO_XYZR % (pdb_file, xyz_tmp) 
+    make_xyz=PDB_TO_XYZR % (pdb_file, xyz_tmp)
     os.system(make_xyz)
+    assert os.path.isfile(xyz_tmp), \
+        "Failed to generate XYZR file using command:\n%s" % make_xyz
     # make surface
     surface_tmp=tempfile.mktemp()
     MSMS=MSMS+" -probe_radius 1.5 -if %s -of %s > "+tempfile.mktemp()
     make_surface=MSMS % (xyz_tmp, surface_tmp)
     os.system(make_surface)
     surface_file=surface_tmp+".vert"
+    assert os.path.isfile(surface_file), \
+        "Failed to generate surface file using command:\n%s" % make_surface
     # read surface vertices from vertex file
     surface=_read_vertex_array(surface_file)
     # clean up tmp files
@@ -100,8 +104,8 @@ def min_dist(coord, surface):
     and surface.
     """
     d=surface-coord
-    d2=sum(d*d, 1)
-    return sqrt(min(d2))
+    d2=numpy.sum(d*d, 1)
+    return numpy.sqrt(min(d2))
 
 def residue_depth(residue, surface):
     """
@@ -156,6 +160,7 @@ class ResidueDepth(AbstractPropertyMap):
 if __name__=="__main__":
 
     import sys
+    from Bio.PDB import PDBParser
 
     p=PDBParser()
     s=p.get_structure("X", sys.argv[1])
