@@ -13,6 +13,7 @@ AbstractConsumer       Base class of all Consumers.
 TaggingConsumer        Consumer that tags output with its event.  For debugging
 SGMLStrippingConsumer  Consumer that strips SGML tags from output.
 EventGenerator         Generate Biopython Events from Martel XML output
+                       (note that Martel is now DEPRECATED)
 
 Functions:
 safe_readline          Read a line from a handle, with check for EOF.
@@ -26,7 +27,6 @@ is_blank_line          Test whether a line is blank.
 """
 
 import sys
-import string
 import traceback
 from types import *
 
@@ -41,12 +41,12 @@ except ImportError:
                      "This causes problems with some ParserSupport modules\n")
     xml_support = 0
 
-class AbstractParser:
+class AbstractParser(object):
     """Base class for other parsers.
 
     """
     def parse(self, handle):
-        raise NotImplementedError, "Please implement in a derived class"
+        raise NotImplementedError("Please implement in a derived class")
 
     def parse_str(self, string):
         return self.parse(File.StringHandle(string))
@@ -59,7 +59,7 @@ class AbstractParser:
             h.close()
         return retval
 
-class AbstractConsumer:
+class AbstractConsumer(object):
     """Base class for other Consumers.
 
     Derive Consumers from this class and implement appropriate
@@ -91,7 +91,7 @@ class TaggingConsumer(AbstractConsumer):
         # be closed or invalid at a later time.
         if handle is None:
             handle = sys.stdout
-	self._handle = handle
+        self._handle = handle
         self._colwidth = colwidth
         self._maxwidth = maxwidth
 
@@ -109,7 +109,7 @@ class TaggingConsumer(AbstractConsumer):
             # Write the tag and line.
             self._handle.write("%-*s: %s\n" % (
                 self._colwidth, name[:self._colwidth],
-                string.rstrip(data[:self._maxwidth-self._colwidth-2])))
+                data[:self._maxwidth-self._colwidth-2].rstrip()))
 
     def __getattr__(self, attr):
         if attr[:6] == 'start_' or attr[:4] == 'end_':
@@ -118,7 +118,7 @@ class TaggingConsumer(AbstractConsumer):
             method = lambda x, a=attr, s=self: s._print_name(a, x)
         return method
 
-class SGMLStrippingConsumer:
+class SGMLStrippingConsumer(object):
     """A consumer that strips off SGML tags.
 
     This is meant to be used as a decorator for other consumers.
@@ -126,7 +126,7 @@ class SGMLStrippingConsumer:
     """
     def __init__(self, consumer):
         if type(consumer) is not InstanceType:
-            raise ValueError, "consumer should be an instance"
+            raise ValueError("consumer should be an instance")
         self._consumer = consumer
         self._prev_attr = None
         self._stripper = File.SGMLStripper()
@@ -157,7 +157,9 @@ if xml_support:
         This acts like a normal SAX handler, and accepts XML generated by
         Martel during parsing. These events are then converted into
         'Biopython events', which can then be caught by a standard
-        biopython consumer
+        biopython consumer.
+
+        Note that Martel is now DEPRECATED.
         """
         def __init__(self, consumer, interest_tags, callback_finalizer = None,
                      exempt_tags = []):
@@ -297,7 +299,7 @@ def read_and_call(uhandle, method, **keywds):
     line = safe_readline(uhandle)
     errmsg = _fails_conditions(*(line,), **keywds)
     if errmsg is not None:
-        raise ValueError, errmsg
+        raise ValueError(errmsg)
     method(line)
 
 def read_and_call_while(uhandle, method, **keywds):
@@ -366,10 +368,10 @@ def _fails_conditions(line, start=None, end=None, contains=None, blank=None,
         if line[:len(start)] != start:
             return "Line does not start with '%s':\n%s" % (start, line)
     if end is not None:
-        if string.rstrip(line)[-len(end):] != end:
+        if line.rstrip()[-len(end):] != end:
             return "Line does not end with '%s':\n%s" % (end, line)
     if contains is not None:
-        if string.find(line, contains) == -1:
+        if line.find(contains) == -1:
             return "Line does not contain '%s':\n%s" % (contains, line)
     if blank is not None:
         if blank:
@@ -396,7 +398,7 @@ def is_blank_line(line, allow_spaces=0):
     if not line:
         return 1
     if allow_spaces:
-        return string.rstrip(line) == ''
+        return line.rstrip() == ''
     return line[0] == '\n' or line[0] == '\r'
 
 def safe_readline(handle):
@@ -408,7 +410,7 @@ def safe_readline(handle):
     """
     line = handle.readline()
     if not line:
-        raise ValueError, "Unexpected end of stream."
+        raise ValueError("Unexpected end of stream.")
     return line
 
 def safe_peekline(handle):
@@ -420,5 +422,5 @@ def safe_peekline(handle):
     """
     line = handle.peekline()
     if not line:
-        raise ValueError, "Unexpected end of stream."
+        raise ValueError("Unexpected end of stream.")
     return line
