@@ -6,16 +6,17 @@
 """PhyloXML reader/parser, writer, and associated functions.
 
 Instantiates tree elements from a parsed PhyloXML file, and constructs an XML
-file from a Bio.Phylo.PhyloXML object.
+file from a `Bio.Phylo.PhyloXML` object.
 
 About capitalization:
 
-    - phyloXML means the file format specification
-    - PhyloXML means the Biopython module Bio.Phylo.PhyloXML and its classes
-    - Phyloxml means the top-level class used by PhyloXMLIO.read (but not
-      Bio.Phylo.read!), containing a list of Phylogenies (Tree-derived objects)
+- phyloXML means the file format specification
+- PhyloXML means the Biopython module `Bio.Phylo.PhyloXML` and its classes
+- Phyloxml means the top-level class used by `PhyloXMLIO.read` (but not
+  `Bio.Phylo.read`!), containing a list of Phylogenies (objects derived from
+  `BaseTree.Tree`)
 """
-__docformat__ = "epytext en"
+__docformat__ = "restructuredtext en"
 
 import sys
 import warnings
@@ -100,7 +101,7 @@ def read(file):
     The children of the root node are phylogenies and possibly other arbitrary
     (non-phyloXML) objects.
 
-    @return: a single Bio.Phylo.PhyloXML.Phyloxml object.
+    :returns: a single `Bio.Phylo.PhyloXML.Phyloxml` object.
     """
     return Parser(file).read()
 
@@ -108,20 +109,22 @@ def parse(file):
     """Iterate over the phylogenetic trees in a phyloXML file.
 
     This ignores any additional data stored at the top level, but may be more
-    memory-efficient than the read() function.
+    memory-efficient than the `read` function.
 
-    @return: a generator of Bio.Phylo.PhyloXML.Phylogeny objects.
+    :returns: a generator of `Bio.Phylo.PhyloXML.Phylogeny` objects.
     """
     return Parser(file).parse()
 
 def write(obj, file, encoding='utf-8', indent=True):
     """Write a phyloXML file.
 
-    The first argument is an instance of Phyloxml, Phylogeny or BaseTree.Tree,
-    or an iterable of either of the latter two. The object will be converted to
-    a Phyloxml object before serialization.
-
-    The file argument can be either an open handle or a file name.
+    :Parameters:
+        obj
+            an instance of `Phyloxml`, `Phylogeny` or `BaseTree.Tree`, or an
+            iterable of either of the latter two. The object will be converted
+            to a Phyloxml object before serialization.
+        file
+            either an open handle or a file name.
     """
     def fix_single(tree):
         if isinstance(tree, PX.Phylogeny):
@@ -207,8 +210,9 @@ def _indent(elem, level=0):
     """Add line breaks and indentation to ElementTree in-place.
 
     Sources:
-        - U{ http://effbot.org/zone/element-lib.htm#prettyprint }
-        - U{ http://infix.se/2007/02/06/gentlemen-indent-your-xml }
+
+    - http://effbot.org/zone/element-lib.htm#prettyprint
+    - http://infix.se/2007/02/06/gentlemen-indent-your-xml
     """
     i = "\n" + level*"  "
     if len(elem):
@@ -260,9 +264,8 @@ def _collapse_wspace(text):
     """Replace all spans of whitespace with a single space character.
 
     Also remove leading and trailing whitespace. See "Collapse Whitespace
-    Policy" in the U{ phyloXML spec glossary
-    <http://phyloxml.org/documentation/version_100/phyloxml.xsd.html#Glossary>
-    }.
+    Policy" in the phyloXML spec glossary:
+    http://phyloxml.org/documentation/version_100/phyloxml.xsd.html#Glossary
     """
     if text is not None:
         return ' '.join(text.split())
@@ -271,9 +274,8 @@ def _collapse_wspace(text):
 def _replace_wspace(text):
     """Replace tab, LF and CR characters with spaces, but don't collapse.
 
-    See "Replace Whitespace Policy" in the U{ phyloXML spec glossary
-    <http://phyloxml.org/documentation/version_100/phyloxml.xsd.html#Glossary>
-    }.
+    See "Replace Whitespace Policy" in the phyloXML spec glossary:
+    http://phyloxml.org/documentation/version_100/phyloxml.xsd.html#Glossary
     """
     for char in ('\t', '\n', '\r'):
         if char in text:
