@@ -84,8 +84,8 @@ following format names:
     files, using Solexa scores with an ASCII offset 64. These can hold Solexa
     scores from -5 to 62.
  - "fastq-illumina" means newer Illumina 1.3 to 1.7 style FASTQ files, using
-    PHRED scores but with an ASCII offset 64, allowing PHRED scores from 0 to
-    62.
+    PHRED scores but with an ASCII offset 64, allowing PHRED scores from 0
+    to 62.
 
 We could potentially add support for "qual-solexa" meaning QUAL files which
 contain Solexa scores, but thus far there isn't any reason to use such files.
@@ -370,6 +370,8 @@ from Bio.SeqRecord import SeqRecord
 from Bio.SeqIO.Interfaces import SequentialSequenceWriter
 from math import log
 import warnings
+from Bio import BiopythonWarning
+
 
 # define score offsets. See discussion for differences between Sanger and
 # Solexa offsets.
@@ -510,9 +512,8 @@ def phred_quality_from_solexa(solexa_quality):
         #Assume None is used as some kind of NULL or NA value; return None
         return None
     if solexa_quality < -5:
-        import warnings
         warnings.warn("Solexa quality less than -5 passed, %s" \
-                      % repr(solexa_quality))
+                      % repr(solexa_quality), BiopythonWarning)
     return 10*log(10**(solexa_quality/10.0) + 1, 10)
 
 def _get_phred_quality(record):
@@ -619,7 +620,8 @@ def _get_sanger_quality_str(record):
         if None in qualities:
             raise TypeError("A quality value of None was found")
         if max(qualities) >= 93.5:
-            warnings.warn("Data loss - max PHRED quality 93 in Sanger FASTQ")
+            warnings.warn("Data loss - max PHRED quality 93 in Sanger FASTQ",
+                          BiopythonWarning)
         #This will apply the truncation at 93, giving max ASCII 126
         return "".join([chr(min(126, int(round(qp))+SANGER_SCORE_OFFSET)) \
                         for qp in qualities])
@@ -642,7 +644,8 @@ def _get_sanger_quality_str(record):
     #Must do this the slow way, first converting the PHRED scores into
     #Solexa scores:
     if max(qualities) >= 93.5:
-        warnings.warn("Data loss - max PHRED quality 93 in Sanger FASTQ")
+        warnings.warn("Data loss - max PHRED quality 93 in Sanger FASTQ",
+                      BiopythonWarning)
     #This will apply the truncation at 93, giving max ASCII 126
     return "".join([chr(min(126, int(round(phred_quality_from_solexa(qs)))+SANGER_SCORE_OFFSET)) \
                     for qs in qualities])
@@ -683,7 +686,8 @@ def _get_illumina_quality_str(record):
         if None in qualities:
             raise TypeError("A quality value of None was found")
         if max(qualities) >= 62.5:
-            warnings.warn("Data loss - max PHRED quality 62 in Illumina FASTQ")
+            warnings.warn("Data loss - max PHRED quality 62 in Illumina FASTQ",
+                          BiopythonWarning)
         #This will apply the truncation at 62, giving max ASCII 126
         return "".join([chr(min(126, int(round(qp))+SOLEXA_SCORE_OFFSET)) \
                         for qp in qualities])
@@ -706,7 +710,8 @@ def _get_illumina_quality_str(record):
     #Must do this the slow way, first converting the PHRED scores into
     #Solexa scores:
     if max(qualities) >= 62.5:
-        warnings.warn("Data loss - max PHRED quality 62 in Illumina FASTQ")
+        warnings.warn("Data loss - max PHRED quality 62 in Illumina FASTQ",
+                      BiopythonWarning)
     #This will apply the truncation at 62, giving max ASCII 126
     return "".join([chr(min(126, int(round(phred_quality_from_solexa(qs)))+SOLEXA_SCORE_OFFSET)) \
                     for qs in qualities])
@@ -747,7 +752,8 @@ def _get_solexa_quality_str(record):
         if None in qualities:
             raise TypeError("A quality value of None was found")
         if max(qualities) >= 62.5:
-            warnings.warn("Data loss - max Solexa quality 62 in Solexa FASTQ")
+            warnings.warn("Data loss - max Solexa quality 62 in Solexa FASTQ",
+                          BiopythonWarning)
         #This will apply the truncation at 62, giving max ASCII 126
         return "".join([chr(min(126, int(round(qs))+SOLEXA_SCORE_OFFSET)) \
                         for qs in qualities])
@@ -771,7 +777,8 @@ def _get_solexa_quality_str(record):
     #Must do this the slow way, first converting the PHRED scores into
     #Solexa scores:
     if max(qualities) >= 62.5:
-        warnings.warn("Data loss - max Solexa quality 62 in Solexa FASTQ")
+        warnings.warn("Data loss - max Solexa quality 62 in Solexa FASTQ",
+                      BiopythonWarning)
     return "".join([chr(min(126,
                             int(round(solexa_quality_from_phred(qp))) + \
                             SOLEXA_SCORE_OFFSET)) \
