@@ -57,7 +57,7 @@ are needed, the 'read' function rather than the 'parse' function might be more a
 """
 
 
-class rd:
+class rd(object):
     """RD (reads), store a read with its name, sequence etc.
     
     The location and strand each read is mapped to is held in the AF lines.
@@ -69,7 +69,7 @@ class rd:
         self.read_tags=None
         self.sequence=''
 
-class qa:
+class qa(object):
     """QA (read quality), including which part if any was used as the consensus."""
     def __init__(self, line=None):
         self.qual_clipping_start=None
@@ -83,7 +83,7 @@ class qa:
             self.align_clipping_start=header[2]
             self.align_clipping_end=header[3]
 
-class ds:
+class ds(object):
     """DS lines, include file name of a read's chromatogram file."""
     def __init__(self, line=None):
         self.chromat_file=''
@@ -105,7 +105,7 @@ class ds:
                 setattr(self,tagpos[p1].lower(),line[p1+len(tagpos[p1])+1:p2].strip())   
 
     
-class af:
+class af(object):
     """AF lines, define the location of the read within the contig.
     
     Note attribute coru is short for complemented (C) or uncomplemented (U),
@@ -122,7 +122,7 @@ class af:
             self.coru = header[2]
             self.padded_start = int(header[3])
 
-class bs:
+class bs(object):
     """"BS (base segment), which read was chosen as the consensus at each position."""
     def __init__(self, line=None):
         self.name=''
@@ -134,7 +134,7 @@ class bs:
             self.padded_end = int(header[2])
             self.name = header[3]
 
-class rt:   
+class rt(object):   
     """RT (transient read tags), generated by crossmatch and phrap."""
     def __init__(self, line=None):
         self.name=''
@@ -153,7 +153,7 @@ class rt:
             self.padded_end=int(header[4])
             self.date=header[5]
 
-class ct:
+class ct(object):
     """CT (consensus tags)."""
     def __init__(self, line=None):
         self.name=''
@@ -176,7 +176,7 @@ class ct:
             if len(header)==7:
                 self.notrans = header[6]
 
-class wa:
+class wa(object):
     """WA (whole assembly tag), holds the assembly program name, version, etc."""
     def __init__(self, line=None):
         self.tag_type=''
@@ -189,7 +189,7 @@ class wa:
             self.program = header[1]
             self.date = header[2]
 
-class wr:
+class wr(object):
     """WR lines."""
     def __init__(self, line=None):
         self.name=''
@@ -203,7 +203,7 @@ class wr:
             self.program = header[2]
             self.date = header[3]
 
-class Reads:
+class Reads(object):
     """Holds information about a read supporting an ACE contig."""
     def __init__(self, line=None):
         self.rd=None    # one per read
@@ -219,7 +219,7 @@ class Reads:
             self.rd.info_items = int(header[3])
             self.rd.read_tags = int(header[4])
         
-class Contig:
+class Contig(object):
     """Holds information about a contig from an ACE record."""
     def __init__(self, line=None):
         self.name = ''
@@ -447,7 +447,7 @@ def parse(handle):
 
         yield record
 
-class ACEFileRecord:
+class ACEFileRecord(object):
     """Holds data of an ACE file.
     """
     def __init__(self):
