@@ -64,7 +64,6 @@ DOCTEST_MODULES = ["Bio.Alphabet",
                    "Bio.AlignIO",
                    "Bio.AlignIO.StockholmIO",
                    "Bio.Blast.Applications",
-                   "Bio.Clustalw",
                    "Bio.Emboss.Applications",
                    "Bio.KEGG.Compound",
                    "Bio.KEGG.Enzyme",
@@ -77,6 +76,7 @@ try:
     import numpy
     DOCTEST_MODULES.extend(["Bio.Statistics.lowess",
                             "Bio.PDB.Polypeptide",
+                            "Bio.PDB.Selection"
                             ])
 except ImportError:
     pass
