@@ -9,6 +9,13 @@ except ImportError:
     raise MissingExternalDependencyError(\
         "Install NumPy if you want to use Bio.KDTree.")
 
+try:
+    from Bio.KDTree import _CKDTree
+except ImportError:
+    from Bio import MissingExternalDependencyError
+    raise MissingExternalDependencyError(\
+        "C module in Bio.KDTree not compiled")
+
 from Bio.KDTree.KDTree import _neighbor_test, _test
 
 nr_points=5000
