@@ -1,4 +1,6 @@
 # Copyright 2001 by Gavin E. Crooks.  All rights reserved.
+# Modifications Copyright 2010 Jeffrey Finkelstein. All rights reserved.
+#
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
@@ -14,6 +16,25 @@ from Bio.SCOP import *
 
 class ScopTests(unittest.TestCase):
 
+    def _compare_cla_lines(self, cla_line_1, cla_line_2):
+        """Compares the two specified Cla lines for equality.
+
+        The order of the key-value pairs in the sixth field of the lines does
+        not matter. For more information, see
+        http://scop.mrc-lmb.cam.ac.uk/scop/release-notes.html.
+        """
+        fields1 = cla_line_1.rstrip().split('\t')
+        fields2 = cla_line_2.rstrip().split('\t')
+        print fields1
+        print fields2
+        # compare the first five fields in a Cla line, which should be exactly
+        # the same
+        if fields1[:5] != fields2[:5]:
+            return False
+        # compare the hierarchy key-value pairs, which are unordered
+        if set(fields1[5].split(',')) != set(fields2[5].split(',')):
+            return False
+        return True
 
     def testParse(self):
   
@@ -35,7 +56,10 @@ class ScopTests(unittest.TestCase):
 
         cla_out = StringIO()
         scop.write_cla(cla_out)
-        self.assertEqual(cla_out.getvalue(), cla)
+        lines = zip(cla.rstrip().split('\n'),
+                    cla_out.getvalue().rstrip().split('\n'))
+        for expected_line, line in lines:
+            self.assertTrue(self._compare_cla_lines(expected_line, line))
         
         des_out = StringIO()
         scop.write_des(des_out)
